@@ -52,7 +52,7 @@ class Window(Gtk.ApplicationWindow):
     __gtype_name__ = "Window"
 
     active_view = GObject.Property(type=GObject.GObject, default=None)
-    selected_items_count = GObject.Property(type=int, default=0, minimum=0)
+    selected_songs_count = GObject.Property(type=int, default=0, minimum=0)
     selection_mode = GObject.Property(type=bool, default=False)
 
     notifications_popup = Gtk.Template.Child()
@@ -73,7 +73,7 @@ class Window(Gtk.ApplicationWindow):
         self._coreselection = app.props.coreselection
 
         self._coreselection.bind_property(
-            "selected-items-count", self, "selected-items-count")
+            "selected-songs-count", self, "selected-songs-count")
 
         self._settings = app.props.settings
         self.add_action(self._settings.create_action('repeat'))
@@ -91,14 +91,13 @@ class Window(Gtk.ApplicationWindow):
         self._view_before_search = None
 
         self._player = app.props.player
+        self._search = app.props.search
 
         self._setup_view()
 
         MediaKeys(self._player, self)
 
     def _setup_view(self):
-        self._search = Search()
-
         self._headerbar = HeaderBar(self._app)
         self._headerbar.props.stack = self._stack
         self._search_headerbar = SearchHeaderBar(self._app)
@@ -127,17 +126,17 @@ class Window(Gtk.ApplicationWindow):
             'back-button-clicked', self._switch_back_from_childview)
 
         self.bind_property(
-            'selected-items-count', self._headerbar, 'selected-items-count')
+            'selected-songs-count', self._headerbar, 'selected-songs-count')
         self.bind_property(
-            "selected-items-count", self._selection_toolbar,
-            "selected-items-count")
+            "selected-songs-count", self._selection_toolbar,
+            "selected-songs-count")
         self.bind_property(
             'selection-mode', self._headerbar, 'selection-mode',
             GObject.BindingFlags.BIDIRECTIONAL
             | GObject.BindingFlags.SYNC_CREATE)
         self.bind_property(
-            "selected-items-count", self._search_headerbar,
-            "selected-items-count")
+            "selected-songs-count", self._search_headerbar,
+            "selected-songs-count")
         self.bind_property(
             "selection-mode", self._search_headerbar, "selection-mode",
             GObject.BindingFlags.BIDIRECTIONAL
@@ -299,6 +298,7 @@ class Window(Gtk.ApplicationWindow):
             # Open search bar on Ctrl + F
             if (keyval == Gdk.KEY_f
                     and not self.views[View.PLAYLIST].rename_active
+                    and not self.props.selection_mode
                     and self._headerbar.props.state != HeaderBar.State.SEARCH):
                 search_mode = self._search.props.search_mode_active
                 self._search.props.search_mode_active = not search_mode
@@ -381,6 +381,7 @@ class Window(Gtk.ApplicationWindow):
                 and (modifiers == shift_mask
                      or modifiers == 0)
                 and not self.views[View.PLAYLIST].rename_active
+                and not self.props.selection_mode
                 and self._headerbar.props.state != HeaderBar.State.SEARCH):
             self._search.props.search_mode_active = True
 
@@ -453,7 +454,7 @@ class Window(Gtk.ApplicationWindow):
         if self.props.active_view == self.views[View.PLAYLIST]:
             return
 
-        selected_songs = self._coreselection.props.selected_items
+        selected_songs = self._coreselection.props.selected_songs
 
         if len(selected_songs) < 1:
             return
